# EHRData

```{eval-rst}
.. module:: ehrdata
    :no-index:
```

## Core Data Structure

```{eval-rst}
.. autosummary::
    :toctree:
    :nosignatures:

    EHRData

```

## Data Type Management

```{eval-rst}
.. autosummary::
    :toctree:
    :nosignatures:

    infer_feature_types
    feature_type_overview
    replace_feature_types
    harmonize_missing_values

```
